slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPRIISetMaximumIterations

Sets the maximum number of inner iterations to be used in the RII solver. These are the Newton iterations related to the computation of the nonlinear Rayleigh functional.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPRIISetMaximumIterations(NEP nep,PetscInt its)

Logically Collective on nep

### Input Parameters

| nep | - nonlinear eigenvalue solver
| its | - maximum inner iterations

### See Also

NEPRIIGetMaximumIterations()

### Level

advanced

### Location

src/nep/impls/rii/rii.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages